@@ -10,7 +10,7 @@
 #  10-Jun-2018 jdw move the base table definitions in terms of content classes
 #  16-Jun-2018 jdw standardize method name for getAttributeDataTypeD()
 #  26-Nov-2018 jdw turn down boundary value level to standard ddl values
-#   3-Feb-2019 jdw get all child items using self.__dApi.getFullDecendentList()
+#   3-Feb-2019 jdw get all child items using self.__dApi.getFullDescendentList()
 #  31-Mar-2019 jdw include parent details in __getAttributeFeatures()
 #   6-Jun-2019 jdw take dictionary API as an argument.
 #  22-Aug-2019 jdw unify naming conventions dictSubset->databaseName and *ForSubset() -> *ForDatabase()
@@ -123,10 +123,14 @@ class ContentDefinition(object):
             #
             self.__categoryFeatures = {catName: self.__getCategoryFeatures(catName, unitCardinalityList, subCategoryD) for catName in self.__categoryList}
             iTypeCodes = contentDefHelper.getTypeCodes("iterable")
+            emiTypeCodes = contentDefHelper.getTypeCodes("embedded_iterable")
+            logger.debug("emiTypeCodes %r", emiTypeCodes)
             iQueryStrings = contentDefHelper.getQueryStrings("iterable")
             logger.debug("iterable types %r iterable query %r", iTypeCodes, iQueryStrings)
             iterableD = self.__getIterables(iTypeCodes, iQueryStrings, contentDefHelper)
+            embeddedIterableD = self.__getEmbeddedIterables(emiTypeCodes)
             logger.debug("iterableD %r", iterableD.items())
+            logger.debug("embeddedIterableD %r", embeddedIterableD.items())
             dataSelectFilterD = contentDefHelper.getDatabaseSelectionFilters(databaseName)
             itemTransformD = contentDefHelper.getItemTransformD()
             logger.debug("itemTransformD %r", itemTransformD.items())
@@ -140,11 +144,14 @@ class ContentDefinition(object):
             self.__sliceParentFiltersD = {}
             self.__sliceUnitCardinalityD = {}
             self.__sliceCategoryExtrasD = {}
+            embeddedIterableD = {}
             logger.warning("Missing dictionary helper method or schema %r", databaseName)
 
         #
         self.__methodD = self.__getMethodInfo()
-        self.__attributeFeatures = OrderedDict({catName: self.__getAttributeFeatures(catName, iterableD, itemTransformD, self.__methodD) for catName in self.__categoryList})
+        self.__attributeFeatures = OrderedDict(
+            {catName: self.__getAttributeFeatures(catName, iterableD, embeddedIterableD, itemTransformD, self.__methodD) for catName in self.__categoryList}
+        )
         self.__attributeDataTypeD = OrderedDict({catName: self.__getAttributeTypeD(catName) for catName in self.__categoryList})
         self.__dataSelectFilterD = dataSelectFilterD
         self.__sliceD = self.__getSliceChildren(self.__sliceParentItemsD)
@@ -185,7 +192,7 @@ class ContentDefinition(object):
         return {}
 
     def __getContentClasses(self, catName, atName=None, wildCardAtName="__all__"):
-        """Return a list of contexts for input categpry and optional attribute.
+        """Return a list of contexts for input category and optional attribute.
 
         Handle the special case of unspecified attributes interpreted as wildcard.
 
@@ -220,7 +227,7 @@ class ContentDefinition(object):
                 sD[parentCategoryName] = [{"PARENT_CATEGORY_NAME": parentCategoryName, "PARENT_ATTRIBUTE_NAME": parentAttributeName, "CHILD_ATTRIBUTE_NAME": parentAttributeName}]
                 #
                 # childItems = self.__dApi.getFullChildList(parentCategoryName, parentAttributeName)
-                childItems = self.__dApi.getFullDecendentList(parentCategoryName, parentAttributeName)
+                childItems = self.__dApi.getFullDescendentList(parentCategoryName, parentAttributeName)
                 # logger.info("Slice parent %s %s  %r" % (parentCategoryName, parentAttributeName, childItems))
                 for childItem in childItems:
                     atName = CifName.attributePart(childItem)
@@ -231,7 +238,7 @@ class ContentDefinition(object):
                     if catName not in sD:
                         sD[catName] = []
                     sD[catName].append({"PARENT_CATEGORY_NAME": parentCategoryName, "PARENT_ATTRIBUTE_NAME": parentAttributeName, "CHILD_ATTRIBUTE_NAME": atName})
-                # Sort the list of dicationaries for each category
+                # Sort the list of dictionaries for each category
                 for catName in sD:
                     sD[catName] = sorted(sD[catName], key=lambda k: (k["PARENT_CATEGORY_NAME"], k["PARENT_ATTRIBUTE_NAME"], k["CHILD_ATTRIBUTE_NAME"]))
 
@@ -257,6 +264,21 @@ class ContentDefinition(object):
         logger.debug("iterableD: %r", list(itD.items()))
         return itD
 
+    def __getEmbeddedIterables(self, iTypeCodes):
+        itD = OrderedDict()
+        #
+        typD = {d["TYPE_CODE"]: d["DELIMITER"] for d in iTypeCodes}
+
+        for catName in self.__categoryList:
+            for atName in self.__categorySchema[catName]:
+                typeCode = self.__dApi.getTypeCode(catName, atName)
+                typeCodeAlt = self.__dApi.getTypeCodeAlt(catName, atName)
+                if typeCode in typD or typeCodeAlt in typD:
+                    itD[(catName, atName)] = typD[typeCode]
+                    continue
+        logger.debug("embedded iterableD: %r", list(itD.items()))
+        return itD
+
     def __getMethodInfo(self):
         methodD = OrderedDict()
         methodIndex = self.__dApi.getMethodIndex()
@@ -480,7 +502,7 @@ class ContentDefinition(object):
             rL.append({"CATEGORY": catName, "ATTRIBUTE": atName})
         return rL
 
-    def __getAttributeFeatures(self, catName, iterableD, itemTransformD, methodD):
+    def __getAttributeFeatures(self, catName, iterableD, embeddedIterableD, itemTransformD, methodD):
         """
         Args:
             catName (string): Category name
@@ -489,7 +511,7 @@ class ContentDefinition(object):
             itemTransformD (dict): dictionary of data transform filters  itd[(catName,atName)] = [f1,f2,...]
 
         Returns:
-            dict: attribure features
+            dict: attribute features
 
 
              cL = self.getCategoryContextList(catName)
@@ -516,6 +538,7 @@ class ContentDefinition(object):
                 "DESCRIPTION_ANNOTATED": [],
                 "IS_KEY": False,
                 "ITERABLE_DELIMITER": None,
+                "EMBEDDED_ITERABLE_DELIMITER": None,
                 "FILTER_TYPES": [],
                 "IS_CHAR_TYPE": False,
                 "METHODS": [],
@@ -561,6 +584,7 @@ class ContentDefinition(object):
             fD["IS_CHAR_TYPE"] = str(pType).lower() in ["char", "uchar"]
             #
             fD["ITERABLE_DELIMITER"] = iterableD[(catName, atName)] if (catName, atName) in iterableD else None
+            fD["EMBEDDED_ITERABLE_DELIMITER"] = embeddedIterableD[(catName, atName)] if (catName, atName) in embeddedIterableD else None
             #
             fD["FILTER_TYPES"] = itemTransformD[(catName, "__all__")] if (catName, "__all__") in itemTransformD else []
             fD["FILTER_TYPES"] = itemTransformD[(catName, atName)] if (catName, atName) in itemTransformD else fD["FILTER_TYPES"]
