@@ -59,7 +59,21 @@ class SchemaDefLoader(object):
 
     """Map PDBx/mmCIF instance data to SQL loadable data using external schema definition."""
 
-    def __init__(self, cfgOb, schemaDefObj, cfgSectionName="site_info_configuration", dbCon=None, cachePath=".", workPath=".", cleanUp=False, warnings="default", verbose=True):
+    def __init__(
+        self,
+        cfgOb,
+        schemaDefObj,
+        cfgSectionName="site_info_configuration",
+        dbCon=None,
+        cachePath=".",
+        workPath=".",
+        cleanUp=False,
+        warnings="default",
+        verbose=True,
+        restoreUseStash=True,
+        restoreUseGit=True,
+        providerTypeExclude=True,
+    ):
         self.__verbose = verbose
         self.__debug = False
         self.__cfgOb = cfgOb
@@ -87,9 +101,9 @@ class SchemaDefLoader(object):
         #
         schemaName = self.__sD.getName()
         modulePathMap = self.__cfgOb.get("DICT_METHOD_HELPER_MODULE_PATH_MAP", sectionName=sectionName)
-        dP = DictionaryApiProviderWrapper(self.__cfgOb, self.__cachePath, useCache=True)
+        dP = DictionaryApiProviderWrapper(self.__cachePath, cfgOb=self.__cfgOb, configName=sectionName, useCache=True)
         dictApi = dP.getApiByName(schemaName)
-        rP = DictMethodResourceProvider(self.__cfgOb, cachePath=self.__cachePath)
+        rP = DictMethodResourceProvider(self.__cfgOb, cachePath=self.__cachePath, restoreUseStash=restoreUseStash, restoreUseGit=restoreUseGit, providerTypeExclude=providerTypeExclude)
         self.__dmh = DictMethodRunner(dictApi, modulePathMap=modulePathMap, resourceProvider=rP)
 
     def setWarning(self, action):
@@ -215,7 +229,7 @@ class SchemaDefLoader(object):
             return [], []
 
     def __exportCsv(self, tableDict, append=False, partName="1"):
-        """"""
+        """ """
         modeOpt = "a" if append else "w"
 
         exportList = []
